@@ -269,47 +269,47 @@ def get_cons(r, w, p_tilde, b, b_splus1, n, bq, net_tax, e, p):
     return cons
 
 
-def get_cm(c_s, p_m, p_tilde, tau_c, alpha_c, method="SS"):
+def get_ci(c_s, p_i, p_tilde, tau_c, alpha_c, method="SS"):
     r"""
-    Compute consumption of good m given amount of composite consumption
+    Compute consumption of good i given amount of composite consumption
     and prices.
 
     .. math::
-        c_{m,j,s,t} = \frac{c_{s,j,t}}{\alpha_{m,j}p_{m,j}}
+        c_{i,j,s,t} = \frac{c_{s,j,t}}{\alpha_{i,j}p_{i,j}}
 
     Args:
         c_s (array_like): composite consumption
-        p_m (array_like): prices for consumption good m
+        p_i (array_like): prices for consumption good i
         p_tilde (array_like): composite good price
         tau_c (array_like): consumption tax rate
         alpha_c (array_like): consumption share parameters
         method (str): adjusts calculation dimensions based on 'SS' or 'TPI'
 
     Returns:
-        c_sm (array_like): consumption of good m
+        c_si (array_like): consumption of good i
     """
     if method == "SS":
-        M = alpha_c.shape[0]
+        I = alpha_c.shape[0]
         S = c_s.shape[0]
         J = c_s.shape[1]
-        tau_c = tau_c.reshape(M, 1, 1)
-        alpha_c = alpha_c.reshape(M, 1, 1)
+        tau_c = tau_c.reshape(I, 1, 1)
+        alpha_c = alpha_c.reshape(I, 1, 1)
         p_tilde.reshape(1, 1, 1)
-        p_m = p_m.reshape(M, 1, 1)
+        p_i = p_i.reshape(I, 1, 1)
         c_s = c_s.reshape(1, S, J)
-        c_sm = alpha_c * (((1 + tau_c) * p_m) / p_tilde) ** (-1) * c_s
+        c_si = alpha_c * (((1 + tau_c) * p_i) / p_tilde) ** (-1) * c_s
     else:  # Time path case
-        M = alpha_c.shape[0]
-        T = p_m.shape[0]
+        I = alpha_c.shape[0]
+        T = p_i.shape[0]
         S = c_s.shape[1]
         J = c_s.shape[2]
-        tau_c = tau_c.reshape(T, M, 1, 1)
-        alpha_c = alpha_c.reshape(1, M, 1, 1)
+        tau_c = tau_c.reshape(T, I, 1, 1)
+        alpha_c = alpha_c.reshape(1, I, 1, 1)
         p_tilde = p_tilde.reshape(T, 1, 1, 1)
-        p_m = p_m.reshape(T, M, 1, 1)
+        p_i = p_i.reshape(T, I, 1, 1)
         c_s = c_s.reshape(T, 1, S, J)
-        c_sm = alpha_c * (((1 + tau_c) * p_m) / p_tilde) ** (-1) * c_s
-    return c_sm
+        c_si = alpha_c * (((1 + tau_c) * p_i) / p_tilde) ** (-1) * c_s
+    return c_si
 
 
 def FOC_savings(
@@ -378,14 +378,36 @@ def FOC_savings(
     if j is not None:
         chi_b = p.chi_b[j]
         beta = p.beta[j]
+        if method == "SS":
+            tax_noncompliance = p.capital_income_tax_noncompliance_rate[-1, j]
+        elif method == "TPI_scalar":
+            tax_noncompliance = p.capital_income_tax_noncompliance_rate[0, j]
+        else:
+            length = r.shape[0]
+            tax_noncompliance = p.capital_income_tax_noncompliance_rate[
+                t : t + length, j
+            ]
     else:
         chi_b = p.chi_b
         beta = p.beta
+        if method == "SS":
+            tax_noncompliance = p.capital_income_tax_noncompliance_rate[-1, :]
+        elif method == "TPI_scalar":
+            tax_noncompliance = p.capital_income_tax_noncompliance_rate[0, :]
+        else:
+            length = r.shape[0]
+            tax_noncompliance = p.capital_income_tax_noncompliance_rate[
+                t : t + length, :
+            ]
     if method == "SS":
         h_wealth = p.h_wealth[-1]
         m_wealth = p.m_wealth[-1]
         p_wealth = p.p_wealth[-1]
         p_tilde = np.ones_like(p.rho) * p_tilde
+    elif method == "TPI_scalar":
+        h_wealth = p.h_wealth[0]
+        m_wealth = p.m_wealth[0]
+        p_wealth = p.p_wealth[0]
     else:
         h_wealth = p.h_wealth[t]
         m_wealth = p.m_wealth[t]
@@ -415,7 +437,17 @@ def FOC_savings(
         - (
             r
             * tax.MTR_income(
-                r, w, b, n, factor, True, e, etr_params, mtry_params, p
+                r,
+                w,
+                b,
+                n,
+                factor,
+                True,
+                e,
+                etr_params,
+                mtry_params,
+                tax_noncompliance,
+                p,
             )
         )
         - tax.MTR_wealth(b, h_wealth, m_wealth, p_wealth)
@@ -512,6 +544,31 @@ def FOC_labor(
         FOC_error (Numpy array): error from FOC for labor supply
 
     """
+    if method == "SS":
+        tau_payroll = p.tau_payroll[-1]
+    elif method == "TPI_scalar":  # for 1st donut ring only
+        tau_payroll = p.tau_payroll[0]
+    else:
+        length = r.shape[0]
+        tau_payroll = p.tau_payroll[t : t + length]
+    if j is not None:
+        if method == "SS":
+            tax_noncompliance = p.labor_income_tax_noncompliance_rate[-1, j]
+        elif method == "TPI_scalar":
+            tax_noncompliance = p.labor_income_tax_noncompliance_rate[0, j]
+        else:
+            tax_noncompliance = p.labor_income_tax_noncompliance_rate[
+                t : t + length, j
+            ]
+    else:
+        if method == "SS":
+            tax_noncompliance = p.labor_income_tax_noncompliance_rate[-1, :]
+        elif method == "TPI_scalar":
+            tax_noncompliance = p.labor_income_tax_noncompliance_rate[0, :]
+        else:
+            tax_noncompliance = p.labor_income_tax_noncompliance_rate[
+                t : t + length, :
+            ]
     if method == "SS":
         tau_payroll = p.tau_payroll[-1]
     elif method == "TPI_scalar":  # for 1st donut ring only
@@ -548,7 +605,17 @@ def FOC_labor(
         1
         - tau_payroll
         - tax.MTR_income(
-            r, w, b, n, factor, False, e, etr_params, mtrx_params, p
+            r,
+            w,
+            b,
+            n,
+            factor,
+            False,
+            e,
+            etr_params,
+            mtrx_params,
+            tax_noncompliance,
+            p,
         )
     )
     FOC_error = marg_ut_cons(cons, p.sigma) * (
