@@ -1118,8 +1118,14 @@ def plot_2D_taxfunc(
     # get tax rates for each point in the income support and plot
     fig, ax = plt.subplots()
     for i, tax_params in enumerate(tax_param_list):
+        if tax_func_type[i] == "mono":
+            tax_params = tax_params[rate_key][s][t][0]
+        else:
+            tax_param_array = np.array(tax_params[rate_key])
+            tax_params = tax_param_array[s, t, :]
         rates = txfunc.get_tax_rates(
-            tax_params[rate_key][s, t, :],
+            # tax_params[rate_key][s, t, :],
+            tax_params,
             X,
             Y,
             None,
